@@ -624,6 +624,10 @@ class ConfParser(object):
                 if self._options.masses:
                     self._confs['mass'] = self._options.masses
 
+            if opt.dest == 'magmoms':
+                if self._options.magmoms:
+                    self._confs['magmom'] = self._options.magmoms
+
             if opt.dest == 'mesh_numbers':
                 if self._options.mesh_numbers:
                     self._confs['mesh_numbers'] = self._options.mesh_numbers
@@ -772,7 +776,7 @@ class ConfParser(object):
                     self.set_parameter('is_mesh_symmetry', False)
 
             if conf_key == 'mesh_symmetry':
-                if confs['mesh_symmetry'] == '.false.':
+                if confs['mesh_symmetry'].lower() == '.false.':
                     self.set_parameter('is_mesh_symmetry', False)
                 
             if conf_key == 'translation':
@@ -783,7 +787,7 @@ class ConfParser(object):
                 self.set_parameter('tsym_type', confs['tsym_type'])
 
             if conf_key == 'rotational':
-                if confs['rotational'] == '.true.':
+                if confs['rotational'].lower() == '.true.':
                     self.set_parameter('is_rotational', True)
 
             if conf_key == 'fc_symmetry':
@@ -816,7 +820,7 @@ class ConfParser(object):
                 self.set_parameter('band_paths', bands)
 
             if conf_key == 'qpoints':
-                if confs['qpoints'] == '.true.':
+                if confs['qpoints'].lower() == '.true.':
                     self.set_parameter('qpoints', True)
                 else:
                     vals = [fracval(x) for x in confs['qpoints'].split()]
